@@ -38,7 +38,6 @@ using Hyena.Data.Sqlite;
 using Hyena.Collections;
 
 using Banshee.Base;
-using Banshee.Preferences;
 using Banshee.ServiceStack;
 using Banshee.Configuration;
 using Banshee.Sources;
@@ -80,7 +79,7 @@ namespace Banshee.Sources
     public abstract class PrimarySource : DatabaseSource, IDisposable
     {
         #region Functions that let us override some behavior of our DatabaseTrackInfos
-
+        
         private TrackEqualHandler track_equal_handler;
         public TrackEqualHandler TrackEqualHandler {
             get { return track_equal_handler; }
@@ -100,7 +99,7 @@ namespace Banshee.Sources
         }
 
         #endregion
-
+    
         protected ErrorSource error_source;
         protected bool error_source_visible = false;
 
@@ -117,7 +116,7 @@ namespace Banshee.Sources
             DELETE FROM CoreArtists WHERE ArtistID NOT IN (SELECT ArtistID FROM CoreTracks);
             DELETE FROM CoreAlbums WHERE AlbumID NOT IN (SELECT AlbumID FROM CoreTracks)
         ");
-
+        
         protected HyenaSqliteCommand purge_tracks_command = new HyenaSqliteCommand (@"
             DELETE FROM CoreTracks WHERE PrimarySourceId = ?
         ");
@@ -133,18 +132,18 @@ namespace Banshee.Sources
                 if (dbid > 0) {
                     return dbid;
                 }
-
+                
                 dbid = ServiceManager.DbConnection.Query<int> ("SELECT PrimarySourceID FROM CorePrimarySources WHERE StringID = ?", UniqueId);
                 if (dbid == 0) {
                     dbid = ServiceManager.DbConnection.Execute ("INSERT INTO CorePrimarySources (StringID) VALUES (?)", UniqueId);
                 } else {
                     SavedCount = ServiceManager.DbConnection.Query<int> ("SELECT CachedCount FROM CorePrimarySources WHERE PrimarySourceID = ?", dbid);
                 }
-
+                
                 if (dbid == 0) {
                     throw new ApplicationException ("dbid could not be resolved, this should never happen");
                 }
-
+                
                 return dbid;
             }
         }
@@ -176,17 +175,17 @@ namespace Banshee.Sources
             get { return is_local; }
             protected set { is_local = value; }
         }
-
+        
         private static SourceSortType[] sort_types = new SourceSortType[] {
             SortNameAscending,
             SortSizeAscending,
             SortSizeDescending
         };
-
+        
         public override SourceSortType[] ChildSortTypes {
             get { return sort_types; }
         }
-
+        
         public override SourceSortType DefaultChildSort {
             get { return SortNameAscending; }
         }
@@ -207,7 +206,7 @@ namespace Banshee.Sources
             get { return null; }
             protected set { base_dir_with_sep = null; }
         }
-
+        
         private string base_dir_with_sep;
         public string BaseDirectoryWithSeparator {
             get { return base_dir_with_sep ?? (base_dir_with_sep = BaseDirectory + System.IO.Path.DirectorySeparatorChar); }
@@ -239,17 +238,6 @@ namespace Banshee.Sources
             set { ExpandedSchema.Set (value); }
         }
 
-        public PathPattern PathPattern { get; private set; }
-
-        protected void SetFileNamePattern (PathPattern pattern)
-        {
-            PathPattern = pattern;
-
-            var file_system = PreferencesPage.Add (new Section ("file-system", Catalog.GetString ("File Organization"), 5));
-            file_system.Add (new SchemaPreference<string> (pattern.FolderSchema, Catalog.GetString ("Folder hie_rarchy")));
-            file_system.Add (new SchemaPreference<string> (pattern.FileSchema, Catalog.GetString ("File _name")));
-        }
-
         public virtual void Dispose ()
         {
             if (Application.ShuttingDown)
@@ -276,7 +264,7 @@ namespace Banshee.Sources
             DatabaseTrackModel.AddCondition (String.Format ("CoreTracks.PrimarySourceID = {0}", DbId));
 
             primary_sources[DbId] = this;
-
+            
             // Load our playlists and smart playlists
             foreach (PlaylistSource pl in PlaylistSource.LoadAll (this)) {
                 AddChildSource (pl);
@@ -347,7 +335,7 @@ namespace Banshee.Sources
             OnTracksChanged ();
         }
 
-        public void NotifyTracksDeleted ()
+        internal void NotifyTracksDeleted ()
         {
             OnTracksDeleted ();
         }
@@ -387,6 +375,15 @@ namespace Banshee.Sources
             get { return true; }
         }
 
+        public override void SetParentSource (Source source)
+        {
+            if (source is PrimarySource) {
+                throw new ArgumentException ("PrimarySource cannot have another PrimarySource as its parent");
+            }
+
+            base.SetParentSource (source);
+        }
+
         protected override void OnTracksAdded ()
         {
             ThreadAssist.SpawnFromMain (delegate {
@@ -434,7 +431,7 @@ namespace Banshee.Sources
         {
             OnTracksDeleted ();
         }
-
+        
         protected virtual void PurgeTracks ()
         {
             ServiceManager.DbConnection.Execute (purge_tracks_command, DbId);
@@ -467,7 +464,7 @@ namespace Banshee.Sources
 
             if (source.Count < 1)
                 return;
-
+            
             ThreadAssist.SpawnFromMain (delegate {
                 CachedList<DatabaseTrackInfo> list = CachedList<DatabaseTrackInfo>.CreateFromModel (source.DatabaseTrackModel);
                 DeleteTrackList (list);
@@ -479,7 +476,7 @@ namespace Banshee.Sources
             if (model == null || model.Count < 1) {
                 return;
             }
-
+            
             ThreadAssist.SpawnFromMain (delegate {
                 CachedList<DatabaseTrackInfo> list = CachedList<DatabaseTrackInfo>.CreateFromModelSelection (model);
                 DeleteTrackList (list);
@@ -524,7 +521,7 @@ namespace Banshee.Sources
                 delete_track_job.Finish ();
                 delete_track_job = null;
             }
-
+            
             if (skip_deletion != null) {
                 list.Remove (skip_deletion);
                 skip_deletion.Clear ();
@@ -535,7 +532,7 @@ namespace Banshee.Sources
             if (list.Count > 0) {
                 ServiceManager.DbConnection.Execute (remove_list_command, DateTime.Now, list.CacheId, list.CacheId);
             }
-
+            
             ThreadAssist.ProxyToMain (delegate {
                 OnTracksDeleted ();
                 OnUserNotifyUpdated ();
@@ -545,16 +542,7 @@ namespace Banshee.Sources
 
         protected virtual bool DeleteTrack (DatabaseTrackInfo track)
         {
-            if (!track.Uri.IsLocalPath)
-                throw new Exception ("Cannot delete a non-local resource: " + track.Uri.Scheme);
-
-            try {
-                Banshee.IO.Utilities.DeleteFileTrimmingParentDirectories (track.Uri);
-            } catch (System.IO.FileNotFoundException) {
-            } catch (System.IO.DirectoryNotFoundException) {
-            }
-
-            return true;
+            throw new Exception ("PrimarySource DeleteTrack method not implemented");
         }
 
         public override bool AcceptsInputFromSource (Source source)
@@ -580,13 +568,13 @@ namespace Banshee.Sources
             }
             return true;
         }
-
+        
         public override bool AddAllTracks (Source source)
         {
             if (!AcceptsInputFromSource (source) || source.Count == 0) {
                 return false;
             }
-
+            
             DatabaseTrackListModel model = (source as ITrackModelSource).TrackModel as DatabaseTrackListModel;
             CachedList<DatabaseTrackInfo> cached_list = CachedList<DatabaseTrackInfo>.CreateFromModel (model);
             if (ThreadAssist.InMainThread) {
@@ -632,7 +620,7 @@ namespace Banshee.Sources
                     IncrementAddedTracks ();
                     break;
                 }
-
+                
                 if (track == null) {
                     IncrementAddedTracks ();
                     continue;
@@ -673,7 +661,7 @@ namespace Banshee.Sources
             if (notify || finished) {
                 OnTracksAdded ();
                 if (finished) {
-                    ThreadAssist.ProxyToMain (OnUserNotifyUpdated);
+                    Banshee.Base.ThreadAssist.ProxyToMain (OnUserNotifyUpdated);
                 }
             }
         }
@@ -696,7 +684,7 @@ namespace Banshee.Sources
                 lock (this) {
                     if (add_track_job == null) {
                         add_track_job = new BatchUserJob (String.Format (Catalog.GetString (
-                            "Adding {0} of {1} to {2}"), "{0}", "{1}", Name),
+                            "Adding {0} of {1} to {2}"), "{0}", "{1}", Name), 
                             Properties.GetStringList ("Icon.Name"));
                         add_track_job.SetResources (Resource.Cpu, Resource.Database, Resource.Disk);
                         add_track_job.PriorityHints = PriorityHints.SpeedSensitive | PriorityHints.DataLossIfStopped;
