@@ -131,7 +131,7 @@ namespace Banshee.Collection.Gui
                 icon_index = GetIconIndex (track);
             }
             
-            if (icon_index < 0) {
+            if (icon_index < 0 || pixbufs == null || pixbufs[icon_index] == null) {
                 return;
             }
             
@@ -142,14 +142,14 @@ namespace Banshee.Collection.Gui
             Cairo.Rectangle pixbuf_area = new Cairo.Rectangle ((cellWidth - render_pixbuf.Width) / 2, 
                 (cellHeight - render_pixbuf.Height) / 2, render_pixbuf.Width, render_pixbuf.Height);
             
-            if (!context.Sensitive) {
+            if (!context.Opaque) {
                 context.Context.Save ();
             }
             
             Gdk.CairoHelper.SetSourcePixbuf (context.Context, render_pixbuf, pixbuf_area.X, pixbuf_area.Y);
             context.Context.Rectangle (pixbuf_area);
             
-            if (!context.Sensitive) {
+            if (!context.Opaque) {
                 context.Context.Clip ();
                 context.Context.PaintWithAlpha (0.5);
                 context.Context.Restore ();
