@@ -48,103 +48,103 @@ namespace Banshee.Widgets
         private string format_string = "<small>{0}</small>";
         private Pango.Layout layout;
         private StreamLabelState state;
-
+        
         public StreamPositionLabel (SeekSlider seekRange) : base (0.0f, 0.0f, 1.0f, 1.0f)
         {
             AppPaintable = true;
-
+            
             this.seekRange = seekRange;
             this.seekRange.ValueChanged += OnSliderUpdated;
         }
-
+        
         protected override void OnRealized ()
         {
             base.OnRealized ();
             BuildLayouts ();
             UpdateLabel ();
         }
-
+        
         private void BuildLayouts ()
         {
             if (layout != null) {
                 layout.Dispose ();
             }
-
+            
             layout = new Pango.Layout (PangoContext);
-            layout.FontDescription = PangoContext.FontDescription;
+            layout.FontDescription = PangoContext.FontDescription.Copy ();
             layout.Ellipsize = Pango.EllipsizeMode.None;
         }
-
+        
         private bool first_style_set = false;
-
+        
         protected override void OnStyleSet (Style old_style)
         {
             base.OnStyleSet (old_style);
-
+            
             if (first_style_set) {
                 BuildLayouts ();
                 UpdateLabel ();
             }
-
+            
             first_style_set = true;
         }
-
+        
         protected override void OnSizeRequested (ref Gtk.Requisition requisition)
         {
             if (!IsRealized || layout == null) {
                 return;
             }
-
+            
             EnsureStyle ();
-
+            
             int width, height;
             layout.GetPixelSize (out width, out height);
-
+            
             requisition.Width = width;
             requisition.Height = height;
         }
-
+        
         protected override bool OnExposeEvent (Gdk.EventExpose evnt)
         {
             int bar_width = (int)((double)Allocation.Width * buffering_progress);
             bool render_bar = false;
-
+            
             if (bar_width > 0 && IsBuffering) {
                 bar_width -= 2 * Style.XThickness;
                 render_bar = true;
-
-                Gtk.Style.PaintBox (Style, GdkWindow, StateType.Normal, ShadowType.In, evnt.Area, this, null,
+                
+                Gtk.Style.PaintBox (Style, GdkWindow, StateType.Normal, ShadowType.In, evnt.Area, this, null, 
                     Allocation.X, Allocation.Y, Allocation.Width, Allocation.Height);
-
+                
                 if (bar_width > 0) {
-                    Gtk.Style.PaintBox (Style, GdkWindow, StateType.Selected, ShadowType.EtchedOut,
-                        evnt.Area, this, "bar",
-                        Allocation.X + Style.XThickness, Allocation.Y + Style.YThickness,
+                    Gtk.Style.PaintBox (Style, GdkWindow, StateType.Selected, ShadowType.EtchedOut, 
+                        evnt.Area, this, "bar", 
+                        Allocation.X + Style.XThickness, Allocation.Y + Style.YThickness, 
                         bar_width, Allocation.Height - 2 * Style.YThickness);
                 }
             }
-
+            
             int width, height;
             layout.GetPixelSize (out width, out height);
-
+            
             int x = Allocation.X + ((Allocation.Width - width) / 2);
             int y = Allocation.Y + ((Allocation.Height - height) / 2);
             Gdk.Rectangle rect = evnt.Area;
-
+            
             if (render_bar) {
                 width = bar_width + Style.XThickness;
                 rect = new Gdk.Rectangle (evnt.Area.X, evnt.Area.Y, width, evnt.Area.Height);
                 Gtk.Style.PaintLayout (Style, GdkWindow, StateType.Selected, true, rect, this, null, x, y, layout);
-
+                
                 rect.X += rect.Width;
                 rect.Width = evnt.Area.Width - rect.Width;
             }
-
+            
             Gtk.Style.PaintLayout (Style, GdkWindow, StateType.Normal, false, rect, this, null, x, y, layout);
-
+            
             return true;
         }
-
+        
         private static string idle = Catalog.GetString ("Idle");
         private static string contacting = Catalog.GetString ("Contacting...");
 
@@ -153,7 +153,7 @@ namespace Banshee.Widgets
             if (!IsRealized || layout == null) {
                 return;
             }
-
+            
             if (IsBuffering) {
                 double progress = buffering_progress * 100.0;
                 UpdateLabel (String.Format ("{0}: {1}%", Catalog.GetString("Buffering"), progress.ToString ("0.0")));
@@ -173,30 +173,30 @@ namespace Banshee.Widgets
                     FormatDuration ((long)seekRange.Value), FormatDuration ((long)seekRange.Adjustment.Upper)));
             }
         }
-
+        
         private void UpdateLabel (string text)
         {
             if (!IsRealized || layout == null) {
                 return;
             }
-
+            
             layout.SetMarkup (String.Format (format_string, GLib.Markup.EscapeText (text)));
             QueueResize ();
         }
-
+        
         private static string FormatDuration (long time)
         {
             time /= 1000;
-            return (time > 3600 ?
+            return (time > 3600 ? 
                     String.Format ("{0}:{1:00}:{2:00}", time / 3600, (time / 60) % 60, time % 60) :
                     String.Format ("{0}:{1:00}", time / 60, time % 60));
         }
-
+        
         private void OnSliderUpdated (object o, EventArgs args)
         {
             UpdateLabel ();
         }
-
+        
         public double BufferingProgress {
             get { return buffering_progress; }
             set {
@@ -205,7 +205,7 @@ namespace Banshee.Widgets
                 QueueDraw ();
             }
         }
-
+        
         public bool IsIdle {
             get { return StreamState == StreamLabelState.Idle; }
         }
@@ -213,7 +213,7 @@ namespace Banshee.Widgets
         public bool IsBuffering {
             get { return StreamState == StreamLabelState.Buffering; }
         }
-
+        
         public bool IsContacting {
             get { return StreamState == StreamLabelState.Contacting; }
         }
@@ -224,7 +224,7 @@ namespace Banshee.Widgets
 
         public StreamLabelState StreamState {
             get { return state; }
-            set {
+            set { 
                 if (state != value) {
                     state = value;
                     UpdateLabel ();
@@ -235,7 +235,7 @@ namespace Banshee.Widgets
 
         public bool IsLive {
             get { return is_live; }
-            set {
+            set { 
                 if (is_live != value) {
                     is_live = value;
                     UpdateLabel ();
@@ -243,9 +243,9 @@ namespace Banshee.Widgets
                 }
             }
         }
-
+        
         public string FormatString {
-            set {
+            set { 
                 format_string = value;
                 BuildLayouts ();
                 UpdateLabel ();
