@@ -31,6 +31,7 @@ using System.Collections.Generic;
 using Mono.Unix;
 
 using Hyena;
+using Hyena.Data.Sqlite;
 
 using Banshee.Base;
 using Banshee.Collection;
@@ -234,8 +235,8 @@ namespace Banshee.Daap
                     database.TrackRemoved += OnDatabaseTrackRemoved;
                     
                     SetStatus (String.Format (Catalog.GetPluralString (
-                        "Loading {0} track.", "Loading {0} tracks.", database.Tracks.Count),
-                        database.Tracks.Count), false
+                        "Loading {0} track", "Loading {0} tracks", database.TrackCount),
+                        database.TrackCount), false
                     );
                     
                     // Notify (eg reload the source before sync is done) at most 5 times
@@ -244,12 +245,22 @@ namespace Banshee.Daap
                     
                     int count = 0;
                     DaapTrackInfo daap_track = null;
+
+                    HyenaSqliteConnection conn = ServiceManager.DbConnection;
+                    conn.BeginTransaction ();
                     foreach (DAAP.Track track in database.Tracks) {
                         daap_track = new DaapTrackInfo (track, this);
                         
                         // Only notify once in a while because otherwise the source Reloading slows things way down
-                        daap_track.Save (++count % notify_every == 0);
+                        if (++count % notify_every == 0) {
+                            conn.CommitTransaction ();
+                            daap_track.Save (true);
+                            conn.BeginTransaction ();
+                        } else {
+                            daap_track.Save (false);
+                        }
                     }
+                    conn.CommitTransaction ();
                     
                     // Save the last track once more to trigger the NotifyTrackAdded
                     if (daap_track != null) {
