@@ -41,10 +41,8 @@ namespace Hyena.Data.Gui
         private ColumnCell header_cell;
         private List<ColumnCell> cells = new List<ColumnCell> ();
         
-        private int minWidth = 0;
-        private int maxWidth = Int32.MaxValue;
-        private double minRelativeWidth = 0;
-        private double relativeWidth = 0;
+        private int min_width = 0;
+        private int max_width = Int32.MaxValue;
         
         public Column (ColumnDescription description) :
             this (description, new ColumnCellText (description.Property, true))
@@ -64,26 +62,32 @@ namespace Hyena.Data.Gui
         public Column (string title, ColumnCell cell, double width, bool visible) 
             : this (null, title, cell, width, visible)
         {
-            this.header_cell = new ColumnHeaderCellText (HeaderCellDataHandler);
         }
         
-        public Column (ColumnCell header_cell, string title, ColumnCell cell, double width)
-            : this (header_cell, title, cell, width, true)
+        public Column (ColumnCell headerCell, string title, ColumnCell cell, double width)
+            : this (headerCell, title, cell, width, true)
         {
         }
         
-        public Column (ColumnCell header_cell, string title, ColumnCell cell, double width, bool visible)
-            : this (header_cell, title, cell, width, visible, 0, Int32.MaxValue)
+        public Column (ColumnCell headerCell, string title, ColumnCell cell, double width, bool visible)
+            : this (headerCell, title, cell, width, visible, 0, Int32.MaxValue)
         {
         }
         
-        public Column (ColumnCell header_cell, string title, ColumnCell cell, double width, bool visible, int minWidth, int maxWidth)
+        public Column (ColumnCell headerCell, string title, ColumnCell cell, double width, bool visible, int minWidth, int maxWidth)
             : base (cell.Property, title, width, visible)
         {
-            this.minWidth = minWidth;
-            this.maxWidth = maxWidth;
-            this.header_cell = header_cell;
-            PackStart(cell);
+            min_width = minWidth;
+            max_width = maxWidth;
+            header_cell = headerCell ?? new ColumnHeaderCellText (HeaderCellDataHandler);
+
+            ColumnCellText header_text = header_cell as ColumnCellText;
+            ColumnCellText cell_text = cell as ColumnCellText;
+            if (header_text != null && cell_text != null) {
+                header_text.Alignment = cell_text.Alignment;
+            }
+
+            PackStart (cell);
         }
         
         private Column HeaderCellDataHandler ()
@@ -93,14 +97,6 @@ namespace Hyena.Data.Gui
         
         public void PackStart (ColumnCell cell)
         {
-            ISizeRequestCell sr_cell = cell as ISizeRequestCell;
-            if (sr_cell != null && sr_cell.RestrictSize) {
-                int w, h;
-                sr_cell.GetSize (out w, out h);
-                MinWidth = w;
-                MaxWidth = w;
-            }
-            
             cells.Insert (0, cell);
         }
         
@@ -138,29 +134,73 @@ namespace Hyena.Data.Gui
             get { return header_cell; }
             set { header_cell = value; }
         }
+
+        public void CalculateWidths (Pango.Layout layout, bool headerVisible, int headerHeight)
+        {
+            bool min_was_zero = MinWidth == 0;
+            bool was_size_req = false;
+            ISizeRequestCell sr_cell = cells[0] as ISizeRequestCell;
+            if (sr_cell != null && sr_cell.RestrictSize) {
+                int min_w, max_w;
+                sr_cell.GetWidthRange (layout, out min_w, out max_w);
+                MinWidth = min_w == -1 ? MinWidth : min_w;
+                MaxWidth = max_w == -1 ? MaxWidth : max_w;
+                was_size_req = true;
+            }
+
+            if (headerVisible && (min_was_zero || was_size_req) && !String.IsNullOrEmpty (Title)) {
+                int w, h;
+                layout.SetText (Title);
+                //column_layout.SetText ("\u2026"); // ellipsis char
+                layout.GetPixelSize (out w, out h);
+
+                // Pretty sure the 3* is needed here only b/c of the " - 8" in ColumnCellText;
+                // See TODO there
+                w += 3 * ColumnHeaderCellText.Spacing;
+                if (this is ISortableColumn) {
+                    w += ColumnHeaderCellText.GetArrowWidth (headerHeight);
+                }
+
+                MinWidth = Math.Max (MinWidth, w);
+
+                // If the min/max are sufficiently close (arbitrarily choosen as < 8px) then
+                // make them equal, so that the column doesn't appear resizable but in reality is on barely.
+                if (MaxWidth - MinWidth < 8) {
+                    MinWidth = MaxWidth;
+                }
+            }
+        }
         
         public int MinWidth {
-            get { return minWidth; }
-            set { minWidth = value; }
-        }
-
-        internal double MinRelativeWidth {
-            get { return minRelativeWidth; }
-            set { minRelativeWidth = value; }
+            get { return min_width; }
+            set {
+                min_width = value;
+                if (value > max_width) {
+                    max_width = value;
+                }
+            }
         }
         
         public int MaxWidth {
-            get { return maxWidth; }
-            set { maxWidth = value; }
-        }
-
-        public double RelativeWidth {
-            get { return relativeWidth; }
-            set { relativeWidth = value; }
+            get { return max_width; }
+            set {
+                max_width = value;
+                if (value < min_width) {
+                    min_width = value;
+                }
+            }
         }
 
+        private string id;
         public string Id {
-            get { return StringUtil.CamelCaseToUnderCase (GetCell (0).Property); }
+            get {
+                if (id == null) {
+                    id = GetCell (0).SubProperty ?? GetCell (0).Property;
+                    id = StringUtil.CamelCaseToUnderCase (id);
+                }
+                return id;
+            }
+            set { id = value; }
         }
     }
 }
