@@ -283,7 +283,7 @@ namespace Hyena.Data.Sqlite
             lock (this) {
                 if (last_reload_fragment != model.ReloadFragment || last_reload_command == null) {
                     last_reload_fragment = model.ReloadFragment;
-                    last_reload_command = new HyenaSqliteCommand (String.Format ("BEGIN; {0}{1}; COMMIT", reload_sql, last_reload_fragment));
+                    last_reload_command = new HyenaSqliteCommand (String.Format ("{0}{1}", reload_sql, last_reload_fragment));
                 }
 
                 Clear ();
@@ -348,11 +348,9 @@ namespace Hyena.Data.Sqlite
 
                 model.Selection.Clear (false);
 
-                using (IDataReader reader = connection.Query (get_selection_command)) {
-                    while (reader.Read ()) {
-                        selected_id = Convert.ToInt64 (reader[0]) - first_id;
-                        model.Selection.QuietSelect ((int)selected_id);
-                    }
+                foreach (long order_id in connection.QueryEnumerable<long> (get_selection_command)) {
+                    selected_id = order_id - first_id;
+                    model.Selection.QuietSelect ((int)selected_id);
                 }
 
                 if (has_select_all_item && model.Selection.Count == 0) {
@@ -436,7 +434,7 @@ namespace Hyena.Data.Sqlite
                     CREATE TEMP TABLE {0} (
                         OrderID INTEGER PRIMARY KEY,
                         ModelID INTEGER,
-                        ItemID INTEGER)", CacheTableName
+                        ItemID TEXT)", CacheTableName
                 ));
             }
 
