@@ -42,6 +42,9 @@ namespace Lastfm.Gui
         private LinkButton signup_button;
         
         private bool save_on_edit = false;
+        
+        private bool save_on_enter = false;
+        private Gtk.Dialog parentDialog;
 
         public AccountLoginForm (Account account) : base (2, 2, false)
         {
@@ -51,7 +54,7 @@ namespace Lastfm.Gui
             RowSpacing = 5;
             ColumnSpacing = 5;
         
-            Label username_label = new Label (Catalog.GetString ("User Name:"));
+            Label username_label = new Label (Catalog.GetString ("Username:"));
             username_label.Xalign = 1.0f;
             username_label.Show ();
             
@@ -64,6 +67,15 @@ namespace Lastfm.Gui
             
             password_entry = new Entry ();
             password_entry.Visibility = false;
+
+            //When the user presses enter in the password field: save, and then destroy the AcountLoginDialog
+            password_entry.Activated += delegate {
+                    if (save_on_enter) {
+                        this.Save ();
+                        parentDialog.Destroy ();
+                    }
+                };
+            
             password_entry.Show ();
             
             Attach (username_label, 0, 1, 0, 1, AttachOptions.Fill, 
@@ -78,14 +90,14 @@ namespace Lastfm.Gui
             Attach (password_entry, 1, 2, 1, 2, AttachOptions.Fill | AttachOptions.Expand, 
                 AttachOptions.Shrink, 0, 0);
                 
-            username_entry.Text = account.UserName;
-            password_entry.Text = account.Password;
+            username_entry.Text = account.UserName ?? String.Empty;
+            password_entry.Text = account.Password ?? String.Empty;
         }
         
         protected override void OnDestroyed ()
         {
             if (save_on_edit) {
-                UpdateLogin ();
+                Save ();
             }
             
             base.OnDestroyed ();
@@ -98,17 +110,14 @@ namespace Lastfm.Gui
             }
             
             Resize (3, 2);
-            signup_button = new LinkButton ("Sign Up for Last.fm");
-            signup_button.Clicked += delegate { account.SignUp (); };
+            signup_button = new LinkButton (account.SignUpUrl, Catalog.GetString ("Sign up for Last.fm"));
             signup_button.Show ();
             Attach (signup_button, 1, 2, 2, 3, AttachOptions.Shrink, AttachOptions.Shrink, 0, 0);
         }
         
-        private void UpdateLogin ()
+        public void Save ()
         {
-            if (account.UserName != username_entry.Text.Trim () ||
-                account.Password != password_entry.Text.Trim ()) {
-                
+            if (account.UserName != username_entry.Text.Trim () || account.Password != password_entry.Text.Trim ()) {
                 account.UserName = username_entry.Text.Trim ();
                 account.Password = password_entry.Text.Trim ();
                 account.Save ();
@@ -120,6 +129,13 @@ namespace Lastfm.Gui
             set { save_on_edit = value; }
         }
         
+        //enable save on Enter and destruction of the parentDialog.
+        public void SaveOnEnter (Gtk.Dialog parentDialog) 
+        {
+           save_on_enter = true;
+           this.parentDialog = parentDialog;
+        }
+                
         public string Username {
             get { return username_entry.Text; }
         }
