@@ -80,7 +80,11 @@ namespace Lastfm.Data
             this.cache_duration = cacheDuration;
             this.xpath = xpath;
 
-            GetData ();
+            try {
+                GetData ();
+            } catch {
+                Refresh ();
+            }
         }
 
         public void Refresh ()
@@ -98,7 +102,11 @@ namespace Lastfm.Data
 
             // Load the XML from the new or cached local file
             doc = new XmlDocument ();
-            using (StreamReader reader = new StreamReader (cache_file)) {
+
+            XmlReaderSettings settings = new XmlReaderSettings ();
+            settings.CheckCharacters = false;
+            
+            using (XmlReader reader = XmlReader.Create (cache_file, settings)) {
                 doc.Load (reader);
             }
 
